@@ -105,10 +105,11 @@ class UserProfile:
     def to_dict(self):
         rv = {
             "id": str(self.user_id),
-            "name": self.name,
-            "gender": self.gender.name,
         }
-
+        if self.name:
+            rv["name"] = self.name
+        if self.gender:
+            rv["gender"] = self.gender.name
         if self.home_address:
             rv["home_address"] = self.home_address.to_dict()
         if self.work_address:
