@@ -69,6 +69,13 @@ def test_user_profile_with_no_home_work_address_to_dict():
         )
 
 
+def test_user_profile_with_no_name_gender_to_dict():
+    user_profile = UserProfile.from_dict(user_profile_dict_with_no_name_or_gender)
+    user_profile_new_dict = user_profile.to_dict()
+
+    assert user_profile_dict_with_no_name_or_gender["id"] == user_profile_new_dict["id"]
+
+
 def test_dict_to_session():
     session = Session.from_dict(session_response)
     assert session.user.id == "30944af3-dfe7-45e5-a860-31ac4a18bc69"
@@ -220,9 +227,7 @@ def test_get_user_from_active_session_for_ok_response():
     session_id = str(uuid4())
 
     def request_callback(request):
-        return HTTPStatus.OK, {}, json.dumps({
-            "data": session_response
-        })
+        return HTTPStatus.OK, {}, json.dumps({"data": session_response})
 
     responses.add_callback(
         responses.GET,
@@ -293,6 +298,10 @@ user_profile_dict_with_no_home_or_work_address = {
     "name": "Test",
 }
 
+user_profile_dict_with_no_name_or_gender = {
+    "id": "f77971a6-3a7f-4475-81b6-2fe9e085f0bc"
+}
+
 incomplete_user_profile_dict = {
     "created_at": "2018-10-18T13:04:55.643673",
     "home_address": {
@@ -354,9 +363,11 @@ def test_mobile_login_with_expiry():
     def request_callback(request):
         payload = json.loads(request.body)
         assert payload["expiry_seconds"] == expiry
-        return HTTPStatus.CREATED, {}, json.dumps({
-            "data": {**session_response, "expiry_seconds": expiry}
-        })
+        return (
+            HTTPStatus.CREATED,
+            {},
+            json.dumps({"data": {**session_response, "expiry_seconds": expiry}}),
+        )
 
     responses.add_callback(
         responses.POST,
@@ -364,5 +375,6 @@ def test_mobile_login_with_expiry():
         callback=request_callback,
         content_type="application/json",
     )
-    user_service.login_with_mobile(phone_number="8130813081", otp="1339", expiry_seconds=expiry)
-
+    user_service.login_with_mobile(
+        phone_number="8130813081", otp="1339", expiry_seconds=expiry
+    )
